pub struct GetTrafficIncidentsInput {
pub skip: Option<u32>,
}Expand description
Returns incidents currently happening on the roads, such as Accidents, Vehicle Breakdowns, Road Blocks, Traffic Diversions etc. Update freq: 2 min
Fields
skip: Option<u32>Number of records to skip for pagination.
Implementations